from sqlalchemy import (
    Boolean,
    Column,
    Integer,
    String,
    DateTime,
    Text,
    ForeignKey,
    Enum,
)
from sqlalchemy.orm import relationship
from sqlalchemy.sql import func
from app.db.base import Base
import enum


class NotificationType(enum.Enum):
    CONNECTION_REQUEST = "connection_request"
    CONNECTION_ACCEPTED = "connection_accepted"
    POST_LIKE = "post_like"
    POST_COMMENT = "post_comment"
    EVENT_INVITATION = "event_invitation"
    EVENT_REMINDER = "event_reminder"
    PRAYER_REQUEST = "prayer_request"
    MINISTRY_ASSIGNMENT = "ministry_assignment"
    DONATION_REMINDER = "donation_reminder"
    BIRTHDAY_REMINDER = "birthday_reminder"
    ANNOUNCEMENT = "announcement"


class Notification(Base):
    __tablename__ = "notifications"

    id = Column(Integer, primary_key=True, index=True)
    recipient_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    sender_id = Column(Integer, ForeignKey("users.id"), nullable=True)
    type = Column(Enum(NotificationType), nullable=False)
    title = Column(String, nullable=False)
    message = Column(Text, nullable=False)
    data = Column(Text, nullable=True)  # JSON data for additional context
    is_read = Column(Boolean, default=False)
    created_at = Column(DateTime, nullable=False, default=func.now())
    read_at = Column(DateTime, nullable=True)

    # Relationships
    recipient = relationship("User", foreign_keys=[recipient_id])
    sender = relationship("User", foreign_keys=[sender_id])


class NotificationSettings(Base):
    __tablename__ = "notification_settings"

    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    email_notifications = Column(Boolean, default=True)
    push_notifications = Column(Boolean, default=True)
    connection_requests = Column(Boolean, default=True)
    post_interactions = Column(Boolean, default=True)
    event_reminders = Column(Boolean, default=True)
    prayer_requests = Column(Boolean, default=True)
    ministry_updates = Column(Boolean, default=True)
    donation_reminders = Column(Boolean, default=True)
    birthday_reminders = Column(Boolean, default=True)
    announcements = Column(Boolean, default=True)

    # Relationships
    user = relationship("User", back_populates="notification_settings")
